Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/__init__.py | 21 | 5 | 0 | 4 | 1 | 76%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/__main__.py | 6 | 0 | 0 | 2 | 1 | 88%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/_version.py | 11 | 2 | 0 | 2 | 1 | 77%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/decoder.py | 69 | 5 | 0 | 34 | 7 | 88%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/docstrings.py | 37 | 2 | 0 | 10 | 0 | 96%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/entry_points.py | 39 | 6 | 0 | 16 | 4 | 78%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/finder.py | 57 | 1 | 0 | 23 | 3 | 95%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/loader.py | 279 | 29 | 0 | 86 | 16 | 85%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/loaders.py | 41 | 4 | 0 | 8 | 0 | 92%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/utils/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/utils/ipython.py | 45 | 45 | 0 | 8 | 0 | 0%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.interactive/lib/python3.9/site-packages/importnb/utils/pytest_importnb.py | 24 | 13 | 0 | 12 | 2 | 58%
Total | 629 | 112 | 0 | 205 | 35 | 80%

No items found using the specified filter.